## Quick help

We strongly recommend that every Faraday user starts by reading our official documentation.
If after reading it you are still in the need of some assistance then we have some recommendations:

- * Maybe someone already had this question before, have you tried the frequently asked questions part of our docs?
- * Not a question but a problem, it could help to take a look at the troubleshooting page
- * Open a ticket

Still can't fix it? You can reach us and find other Faraday users on:

- * User support - support.faradaysec.com
- * Twitter - twitter.com/faradaysec

More info about Faraday at faradaysec.com